.. SPDX-FileCopyrightText: Copyright © 2024 Idiap Research Institute <contact@idiap.ch>
..
.. SPDX-License-Identifier: GPL-3.0-or-later

.. _mednet.databases.segment.rimoner3:

==============
 RIM One (r3)
==============

* DataModule and support code: :py:mod:`.data.segment.rimoner3`
* Splits:

  .. list-table::
     :align: left

     * - Config. key
       - Module
     * - ``rimoner3-cup``
       - :py:mod:`.config.segment.data.rimoner3.cup_exp1`
     * - ``rimoner3-disc``
       - :py:mod:`.config.segment.data.rimoner3.disc_exp1`
     * - ``rimoner3-cup-2nd``
       - :py:mod:`.config.segment.data.rimoner3.cup_exp2`
     * - ``rimoner3-disc-2nd``
       - :py:mod:`.config.segment.data.rimoner3.disc_exp2`
